<?php

namespace Drupal\izi_message\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\Core\Render\Markup;

/**
 * Defines a form that configures izi message settings.
 */
class IziMessageSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'izi_message_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['izi_message.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $config = $this->config('izi_message.settings')->getRawData();
    $form = \Drupal::service('plugin.manager.izi_message_field')->form($config, $form);

    $link = Link::fromTextAndUrl($this->t('IZITOAST'), Url::fromUri('https://izitoast.marcelodolza.com/', [
      'fragment' => 'Welcome',
      'attributes' => [
        'target' => '_blank'
      ]
    ]))->toString()->__toString();

    $form['info_library'] = [
      '#markup' => $this->t('<b>This module uses @link library</b>', [
        '@link' => Markup::create($link),
      ], [
        'context' => 'izi_message'
      ]),
      '#weight' => -1000,
    ];
    
    
    $form['actions']['submit']['#value'] = $this->t('Update settings @module', [
      '@module' => 'izi Message',
    ],[
      'context' => 'izi_message'
    ]);

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config       = $this->configFactory()->getEditable('izi_message.settings');
    $definitions  = \Drupal::service('plugin.manager.izi_message_field')->getDefinitions();
    $values       = $form_state->getValues();

    foreach ($definitions as $key => $definition) {
      if($value = $form_state->getValue($definition['id'])) {
        $config->set($definition['id'], $value);
      }
    }

    $config->save();
    parent::submitForm($form, $form_state);
  }
  
}
