<?php

namespace Drupal\izi_message;

use Drupal\Component\Plugin\PluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Each izi message field will extend this base.
 */
abstract class iziMessageFieldBasic extends PluginBase {
  use StringTranslationTrait;

  /**
   * Machine name of the izi message field plugin.
   *
   * @var string
   */
  protected $id;

  /**
   * The title of the plugin.
   *
   * @var \Drupal\Core\Annotation\Translation
   *
   * @ingroup plugin_translatable
   */
  protected $label;

  /**
   * The value of the izi message field in this instance.
   *
   * @var mixed
   */
  protected $value;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, array $plugin_definition) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->id           = $plugin_definition['id'];
    $this->label        = $plugin_definition['label'];
  }

  /**
   * Obtain the izi message field's internal ID.
   *
   * @return string
   *   This izi message field's internal ID.
   */
  public function id() {
    return $this->id;
  }

  /**
   * This izi message field's label.
   *
   * @return string
   *   The label.
   */
  public function label() {
    if($this->label instanceof \Drupal\Core\StringTranslation\TranslatableMarkup) {
      return $this->label->render();
    }
    return $this->label;
  }

  /**
   * Generate a form element for thisizi message field.
   *
   * @param array $element
   *   The existing form element to attach to.
   *
   * @return array
   *   The completed form element.
   */

  abstract public function form(array $element);

  /**
   * Validates 
   *
   * @param array $element
   *   The form element to process.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state.
   */
  public static function validate(array &$element, FormStateInterface $form_state) {}

  /**
   * Obtain the current izi message field's raw value.
   *
   * @return string
   *   The current raw izi message field's value.
   */
  public function value() {
    return $this->value;
  }

  /**
   * Assign the current izi message field a value.
   *
   * @param string $value
   *   The value to assign this izi message field.
   */
  public function setValue($value) {
    $this->value = $value;
  }

}