<?php

namespace Drupal\izi_message;

use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\izi_message\Annotation\iziMessageField;
use Drupal\izi_message\iziMessageFieldInterface;
use Drupal\izi_message\iziMessageFieldBasic;

/**
 * A Plugin to manage your izi message settings.
 */
class iziMessageFieldPluginManager extends DefaultPluginManager{

  /**
   * {@inheritdoc}
   */
  public function __construct(\Traversable $namespaces, CacheBackendInterface $cache_backend, ModuleHandlerInterface $module_handler) {
    parent::__construct('Plugin/iziMessageField', $namespaces, $module_handler, iziMessageFieldBasic::class, iziMessageField::class);
    $this->alterInfo('izi_message_field');
    $this->setCacheBackend($cache_backend, 'izi_message_field');
  }

  /**
   * Invokes the hook to alter the definitions if the alter hook is set.
   *  
   * @param $definitions
   *   The discovered plugin definitions.
   */
  protected function alterDefinitions(&$definitions) {
    parent::alterDefinitions($definitions);

    // remove plugins that do not inherit from the base
    foreach($definitions as $key=>$plugin){
      if(!(is_subclass_of($plugin['class'], $this->pluginInterface))) {
        unset($definitions[$key]);
      };
    }
  }


  /**
   * {@inheritdoc}
   */
  public function form(array $values, array $element) {
    $definitions = $this->getDefinitions();

    foreach ($definitions as $key => $definition) {
      $field = $this->createInstance($definition['id']);
      $field_value = isset($values[$key]) ? $values[$key] : NULL;
      $field->setValue($field_value);
      $element[$key] = $field->form($element);
    }

    return $element;
  }

}
